%CODIFICACIÓN DE LA ENVOLVENTE.
%function [LARc,ACF,LARantc,d]=stpc(s,LARantc)
%Entradas:
%so:trama de entrada de 160 muestras muestreadas a 8KHz y cuantificadas con 13 bits preprocesada.
%LARantc:LAR de la trama anterior.
%Salidas:
%LARc:LAR codificados.
%ACF:términos de autocorrelación para el vad.
%LARantc:LAR anteriores para la siguiente trama.
%d:señal sin envolvente para posterior procesado.
function [LARc,ACF,LARantc,d]=stpc(s,LARantc)
ACF=autocorr(s);%calculamos los coeficientes de autocorrelación.
r=rschur(ACF);%calculamos los coeficientes de reflexión.
LAR=logarea(r);%calculamos los LAR.
LARc=larcod(LAR);%codificamos los LAR.
LARact=lardec(LARc);%decodificamos los LAR codificados.
LARi=interpol(LARact,LARantc);%interpolamos los LAR con los de la trama anterior.
LARantc=LARact;%actualizamos los LAR de la trama anterior para la siguiente trama.
rp=reflect(LARi);%calculamos los coeficientes de reflexión a partir de los LAR interpolados.
d=invfilt(s,rp);%aplicamos el filtro que elimina la envolvente.